@@ -11,9 +11,7 @@ from legaltech_api_client.types import Response
 def _get_kwargs(
     *,
     client: Client,
-    form_data: ClaimCreateRequest,
-    multipart_data: ClaimCreateRequest,
-    json_body: ClaimCreateRequest,
+    data: ClaimCreateRequest,
     authorization: str,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/claims/".format(client.base_url)
@@ -23,17 +21,13 @@ def _get_kwargs(
 
     headers["Authorization"] = authorization
 
-    json_body.to_dict()
-
-    multipart_data.to_multipart()
-
     return {
         "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
-        "json": form_data.to_dict(),
+        "json": data.to_dict(),
     }
 
 
@@ -66,17 +60,15 @@ def _build_response(*, response: httpx.Response) -> Response[Union[Any, ClaimRes
 def sync_detailed(
     *,
     client: Client,
-    form_data: ClaimCreateRequest,
-    multipart_data: ClaimCreateRequest,
-    json_body: ClaimCreateRequest,
+    data: ClaimCreateRequest,
     authorization: str,
 ) -> Response[Union[Any, ClaimResponse]]:
     """Create claims
 
     Args:
+        client: Client:
+        data (ClaimCreateRequest):
         authorization (str):
-        multipart_data (ClaimCreateRequest):
-        json_body (ClaimCreateRequest):
 
     Returns:
         Response[Union[Any, ClaimResponse]]
@@ -84,9 +76,7 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     )
 
@@ -101,17 +91,15 @@ def sync_detailed(
 def sync(
     *,
     client: Client,
-    form_data: ClaimCreateRequest,
-    multipart_data: ClaimCreateRequest,
-    json_body: ClaimCreateRequest,
+    data: ClaimCreateRequest,
     authorization: str,
 ) -> Optional[Union[Any, ClaimResponse]]:
     """Create claims
 
     Args:
+        client (Client):
+        data (ClaimCreateRequest):
         authorization (str):
-        multipart_data (ClaimCreateRequest):
-        json_body (ClaimCreateRequest):
 
     Returns:
         Response[Union[Any, ClaimResponse]]
@@ -119,9 +107,7 @@ def sync(
 
     return sync_detailed(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     ).parsed
 
@@ -129,17 +115,15 @@ def sync(
 async def asyncio_detailed(
     *,
     client: Client,
-    form_data: ClaimCreateRequest,
-    multipart_data: ClaimCreateRequest,
-    json_body: ClaimCreateRequest,
+    data: ClaimCreateRequest,
     authorization: str,
 ) -> Response[Union[Any, ClaimResponse]]:
     """Create claims
 
     Args:
+        client (Client):
+        data (ClaimCreateRequest):
         authorization (str):
-        multipart_data (ClaimCreateRequest):
-        json_body (ClaimCreateRequest):
 
     Returns:
         Response[Union[Any, ClaimResponse]]
@@ -147,9 +131,7 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     )
 
@@ -162,17 +144,15 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: Client,
-    form_data: ClaimCreateRequest,
-    multipart_data: ClaimCreateRequest,
-    json_body: ClaimCreateRequest,
+    data: ClaimCreateRequest,
     authorization: str,
 ) -> Optional[Union[Any, ClaimResponse]]:
     """Create claims
 
     Args:
+        client (Client):
+        data (ClaimCreateRequest):
         authorization (str):
-        multipart_data (ClaimCreateRequest):
-        json_body (ClaimCreateRequest):
 
     Returns:
         Response[Union[Any, ClaimResponse]]
@@ -181,9 +161,7 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
-            form_data=form_data,
-            multipart_data=multipart_data,
-            json_body=json_body,
+            data=data,
             authorization=authorization,
         )
     ).parsed
