@@ -9,12 +9,10 @@ from legaltech_api_client.types import Response
 
 
 def _get_kwargs(
-    *,
-    client: Client,
-    form_data: CustomerCreateRequest,
-    multipart_data: CustomerCreateRequest,
-    json_body: CustomerCreateRequest,
-    authorization: str,
+        *,
+        client: Client,
+        data: CustomerCreateRequest,
+        authorization: str,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/customers/".format(client.base_url)
 
@@ -23,17 +21,13 @@ def _get_kwargs(
 
     headers["Authorization"] = authorization
 
-    json_body.to_dict()
-
-    multipart_data.to_multipart()
-
     return {
         "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
         "timeout": client.get_timeout(),
-        "json": form_data.to_dict(),
+        "json": data.to_dict(),
     }
 
 
@@ -64,19 +58,17 @@ def _build_response(*, response: httpx.Response) -> Response[Union[Any, Customer
 
 
 def sync_detailed(
-    *,
-    client: Client,
-    form_data: CustomerCreateRequest,
-    multipart_data: CustomerCreateRequest,
-    json_body: CustomerCreateRequest,
-    authorization: str,
+        *,
+        client: Client,
+        data: CustomerCreateRequest,
+        authorization: str,
 ) -> Response[Union[Any, CustomerCreateResponse]]:
     """Create new Customer.
 
     Args:
+        client (Client):
+        data (CustomerCreateRequest):
         authorization (str):
-        multipart_data (CustomerCreateRequest):
-        json_body (CustomerCreateRequest):
 
     Returns:
         Response[Union[Any, CustomerCreateResponse]]
@@ -84,9 +76,7 @@ def sync_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     )
 
@@ -99,19 +89,17 @@ def sync_detailed(
 
 
 def sync(
-    *,
-    client: Client,
-    form_data: CustomerCreateRequest,
-    multipart_data: CustomerCreateRequest,
-    json_body: CustomerCreateRequest,
-    authorization: str,
+        *,
+        client: Client,
+        data: CustomerCreateRequest,
+        authorization: str,
 ) -> Optional[Union[Any, CustomerCreateResponse]]:
     """Create new Customer.
 
     Args:
+        client (Client):
+        data (CustomerCreateRequest):
         authorization (str):
-        multipart_data (CustomerCreateRequest):
-        json_body (CustomerCreateRequest):
 
     Returns:
         Response[Union[Any, CustomerCreateResponse]]
@@ -119,27 +107,23 @@ def sync(
 
     return sync_detailed(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     ).parsed
 
 
 async def asyncio_detailed(
-    *,
-    client: Client,
-    form_data: CustomerCreateRequest,
-    multipart_data: CustomerCreateRequest,
-    json_body: CustomerCreateRequest,
-    authorization: str,
+        *,
+        client: Client,
+        data: CustomerCreateRequest,
+        authorization: str,
 ) -> Response[Union[Any, CustomerCreateResponse]]:
     """Create new Customer.
 
     Args:
+        client (Client):
+        data (CustomerCreateRequest):
         authorization (str):
-        multipart_data (CustomerCreateRequest):
-        json_body (CustomerCreateRequest):
 
     Returns:
         Response[Union[Any, CustomerCreateResponse]]
@@ -147,9 +131,7 @@ async def asyncio_detailed(
 
     kwargs = _get_kwargs(
         client=client,
-        form_data=form_data,
-        multipart_data=multipart_data,
-        json_body=json_body,
+        data=data,
         authorization=authorization,
     )
 
@@ -160,19 +142,17 @@ async def asyncio_detailed(
 
 
 async def asyncio(
-    *,
-    client: Client,
-    form_data: CustomerCreateRequest,
-    multipart_data: CustomerCreateRequest,
-    json_body: CustomerCreateRequest,
-    authorization: str,
+        *,
+        client: Client,
+        data: CustomerCreateRequest,
+        authorization: str,
 ) -> Optional[Union[Any, CustomerCreateResponse]]:
     """Create new Customer.
 
     Args:
+        client (Client):
+        data (CustomerCreateRequest):
         authorization (str):
-        multipart_data (CustomerCreateRequest):
-        json_body (CustomerCreateRequest):
 
     Returns:
         Response[Union[Any, CustomerCreateResponse]]
@@ -181,9 +161,7 @@ async def asyncio(
     return (
         await asyncio_detailed(
             client=client,
-            form_data=form_data,
-            multipart_data=multipart_data,
-            json_body=json_body,
+            data=data,
             authorization=authorization,
         )
     ).parsed
